<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fi" sourcelanguage="en">
<context>
    <name>AgendaPlug</name>
    <message>
        <location filename="../AgendaPlug.cpp" line="26"/>
        <source>Jump to today</source>
        <translation>Siirry tähän päivään</translation>
    </message>
    <message>
        <location filename="../AgendaPlug.cpp" line="27"/>
        <source>Jump to</source>
        <translation>Siirry</translation>
    </message>
    <message>
        <location filename="../AgendaPlug.cpp" line="28"/>
        <location filename="../AgendaPlug.cpp" line="122"/>
        <source>New event</source>
        <translation>Uusi tapahtuma</translation>
    </message>
    <message>
        <location filename="../AgendaPlug.h" line="17"/>
        <source>Agenda</source>
        <translation>Merkinnät</translation>
    </message>
</context>
<context>
    <name>AlarmPickDialog</name>
    <message>
        <location filename="../AlarmPickDialog.ui" line="6"/>
        <source>Alarm</source>
        <translation>Hälytys</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="27"/>
        <source>Time in advance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="37"/>
        <source>Hours</source>
        <translation>Tunnit</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="57"/>
        <source>Minutes</source>
        <translation>Minuutit</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="77"/>
        <source>Seconds</source>
        <translation>Sekunnit</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.ui" line="17"/>
        <source>Enable</source>
        <translation>Ota käyttöön</translation>
    </message>
    <message>
        <location filename="../AlarmPickDialog.cpp" line="13"/>
        <source>Done</source>
        <translation>Valmis</translation>
    </message>
</context>
<context>
    <name>AlarmPickSelector</name>
    <message>
        <location filename="../AlarmPickSelector.cpp" line="26"/>
        <source>None</source>
        <translation>Ei mitään</translation>
    </message>
    <message>
        <location filename="../AlarmPickSelector.cpp" line="37"/>
        <source>Exact</source>
        <translation>Tapahtumahetki</translation>
    </message>
    <message numerus="yes">
        <location filename="../AlarmPickSelector.cpp" line="39"/>
        <source>%n hour(s) before</source>
        <translation>
            <numerusform>%n tunti ennen</numerusform>
            <numerusform>%n tuntia ennen</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../AlarmPickSelector.cpp" line="40"/>
        <source>%n minute(s) before</source>
        <translation>
            <numerusform>%n minuutti ennen</numerusform>
            <numerusform>%n minuuttia ennen</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../AlarmPickSelector.cpp" line="41"/>
        <source>%n second(s) before</source>
        <translation>
            <numerusform>%n sekunti ennen</numerusform>
            <numerusform>%n sekuntia ennen</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../AlarmPickSelector.cpp" line="43"/>
        <source>%1:%2:%3 before</source>
        <translation>%1:%2:%3 ennen</translation>
    </message>
</context>
<context>
    <name>ByDayWidget</name>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="22"/>
        <source>From beginning</source>
        <translation>Alusta</translation>
    </message>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="23"/>
        <source>From end</source>
        <translation>Lopusta</translation>
    </message>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="33"/>
        <source>By day of month</source>
        <translation>Kuukaudenpäivän mukaan</translation>
    </message>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="35"/>
        <source>By week of year</source>
        <translation>Viikon mukaan</translation>
    </message>
    <message>
        <location filename="../recurrence/ByDayWidget.cpp" line="37"/>
        <source>By day of year</source>
        <translation>Vuodenpäivän mukaan</translation>
    </message>
</context>
<context>
    <name>ByMonthWidget</name>
    <message>
        <location filename="../recurrence/ByMonthWidget.cpp" line="21"/>
        <source>By month</source>
        <translation>Kuukauden mukaan</translation>
    </message>
</context>
<context>
    <name>ByWeekdayWidget</name>
    <message>
        <location filename="../recurrence/ByWeekdayWidget.cpp" line="18"/>
        <source>By day of week</source>
        <translation>Viikonpäivän mukaan</translation>
    </message>
    <message>
        <location filename="../recurrence/ByWeekdayWidget.cpp" line="36"/>
        <source>From beginning</source>
        <translation>Alusta</translation>
    </message>
    <message>
        <location filename="../recurrence/ByWeekdayWidget.cpp" line="37"/>
        <source>From end</source>
        <translation>Lopusta</translation>
    </message>
</context>
<context>
    <name>CalendarEditDialog</name>
    <message>
        <location filename="../settings/CalendarEditDialog.ui" line="6"/>
        <source>Edit calendar</source>
        <translation>Muokkaa kalenteria</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.ui" line="56"/>
        <source>Color</source>
        <translation>Väri</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.ui" line="66"/>
        <source>Visible</source>
        <translation>Näkyvä</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="26"/>
        <source>Export</source>
        <translation>Vie</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="27"/>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="28"/>
        <source>Save</source>
        <translation>Tallenna</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="131"/>
        <source>Save file</source>
        <translation>Tallenna tiedosto</translation>
    </message>
    <message>
        <location filename="../settings/CalendarEditDialog.cpp" line="144"/>
        <source>Delete this calendar and its events, tasks and notes?</source>
        <translation>Poistetaanko kalenteri ja sen tapahtumat, tehtävät sekä muistiinpanot?</translation>
    </message>
</context>
<context>
    <name>CalendarPickDialog</name>
    <message>
        <location filename="../CalendarPickDialog.ui" line="6"/>
        <source>Calendar</source>
        <translation>Kalenteri</translation>
    </message>
</context>
<context>
    <name>CalendarsConfigDialog</name>
    <message>
        <location filename="../settings/CalendarsConfigDialog.ui" line="6"/>
        <source>Edit calendars</source>
        <translation>Muokkaa kalentereita</translation>
    </message>
    <message>
        <location filename="../settings/CalendarsConfigDialog.cpp" line="25"/>
        <source>New</source>
        <translation>Uusi</translation>
    </message>
</context>
<context>
    <name>CalendarsConfigSelector</name>
    <message numerus="yes">
        <location filename="../settings/CalendarsConfigSelector.cpp" line="16"/>
        <source>%n visible</source>
        <translation>
            <numerusform>%n näkyvissä</numerusform>
            <numerusform>%n näkyvissä</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ColorPickDialog</name>
    <message>
        <location filename="../ColorPickDialog.ui" line="6"/>
        <source>Color</source>
        <translation>Väri</translation>
    </message>
    <message>
        <location filename="../ColorPickDialog.cpp" line="12"/>
        <source>Done</source>
        <translation>Valmis</translation>
    </message>
</context>
<context>
    <name>ComponentEditDialog</name>
    <message>
        <location filename="../ComponentEditDialog.h" line="22"/>
        <source>Save</source>
        <translation>Tallenna</translation>
    </message>
    <message>
        <location filename="../ComponentEditDialog.h" line="29"/>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
</context>
<context>
    <name>ComponentListDelegate</name>
    <message>
        <location filename="../ComponentListDelegate.h" line="80"/>
        <source>All
day</source>
        <translation>Koko
päivä</translation>
    </message>
</context>
<context>
    <name>ComponentListWidget</name>
    <message>
        <location filename="../ComponentListWidget.cpp" line="72"/>
        <source>Edit</source>
        <translation>Muokkaa</translation>
    </message>
    <message>
        <location filename="../ComponentListWidget.cpp" line="73"/>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
</context>
<context>
    <name>ComponentWidget</name>
    <message>
        <location filename="../week/ComponentWidget.cpp" line="181"/>
        <source>Edit</source>
        <translation>Muokkaa</translation>
    </message>
    <message>
        <location filename="../week/ComponentWidget.cpp" line="182"/>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
</context>
<context>
    <name>DatePickDialog</name>
    <message>
        <location filename="../DatePickDialog.cpp" line="27"/>
        <source>Done</source>
        <translation>Valmis</translation>
    </message>
    <message>
        <location filename="../DatePickDialog.cpp" line="180"/>
        <source>Week %1 (%2 - %3)</source>
        <translation>Viikko %1 (%2 - %3)</translation>
    </message>
    <message>
        <location filename="../DatePickDialog.ui" line="6"/>
        <source>Select date</source>
        <translation>Valitse päivä</translation>
    </message>
</context>
<context>
    <name>DayNumberDialog</name>
    <message>
        <location filename="../recurrence/DayNumberDialog.h" line="17"/>
        <source>Enter day number</source>
        <translation>Syötä  päivän numero</translation>
    </message>
    <message>
        <location filename="../recurrence/DayNumberDialog.h" line="24"/>
        <source>Add</source>
        <translation>Lisää</translation>
    </message>
</context>
<context>
    <name>DayWindow</name>
    <message>
        <location filename="../DayWindow.ui" line="35"/>
        <source>Previous day</source>
        <translation>Edellinen päivä</translation>
    </message>
    <message>
        <location filename="../DayWindow.ui" line="40"/>
        <source>Next day</source>
        <translation>Seuraava päivä</translation>
    </message>
    <message>
        <location filename="../DayWindow.ui" line="45"/>
        <source>Jump to today</source>
        <translation>Siirry tähän päivään</translation>
    </message>
    <message>
        <location filename="../DayWindow.ui" line="50"/>
        <source>Jump to</source>
        <translation>Siirry</translation>
    </message>
    <message>
        <location filename="../DayWindow.cpp" line="36"/>
        <source>New event</source>
        <translation>Uusi tapahtuma</translation>
    </message>
</context>
<context>
    <name>DetailedCalendarDelegate</name>
    <message numerus="yes">
        <location filename="../settings/DetailedCalendarDelegate.h" line="30"/>
        <source>%n event(s)</source>
        <translation>
            <numerusform>%n tapahtuma</numerusform>
            <numerusform>%n tapahtumaa</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/DetailedCalendarDelegate.h" line="31"/>
        <source>%n task(s)</source>
        <translation>
            <numerusform>%n tehtävä</numerusform>
            <numerusform>%n tehtävää</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/DetailedCalendarDelegate.h" line="32"/>
        <source>%n note(s)</source>
        <translation>
            <numerusform>%n muistiinpano</numerusform>
            <numerusform>%n muistiinpanoa</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>EventEditDialog</name>
    <message>
        <location filename="../EventEditDialog.ui" line="27"/>
        <source>Title</source>
        <translation>Otsikko</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="40"/>
        <source>Where</source>
        <translation>Sijainti</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="55"/>
        <source>All day</source>
        <translation>Koko päivä</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="64"/>
        <source>From</source>
        <translation>Alkaa</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="90"/>
        <source>To</source>
        <translation>Päättyy</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="118"/>
        <source>Repeat</source>
        <translation>Toista</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="128"/>
        <source>Calendar</source>
        <translation>Kalenteri</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.ui" line="135"/>
        <source>Alarm</source>
        <translation>Hälytys</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.cpp" line="69"/>
        <source>Edit event</source>
        <translation>Muokkaa tapahtumaa</translation>
    </message>
    <message>
        <location filename="../EventEditDialog.cpp" line="87"/>
        <source>New event</source>
        <translation>Uusi tapahtuma</translation>
    </message>
</context>
<context>
    <name>EventWindow</name>
    <message>
        <location filename="../EventWindow.ui" line="6"/>
        <source>Event</source>
        <translation>Tapahtuma</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="62"/>
        <source>To</source>
        <translation>Päättyy</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="86"/>
        <source>Repeat</source>
        <translation>Toista</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="110"/>
        <source>Alarm</source>
        <translation>Hälytys</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="177"/>
        <source>Previous event</source>
        <translation>Edellinen tapahtuma</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="182"/>
        <source>Next event</source>
        <translation>Seuraava tapahtuma</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="187"/>
        <source>Edit event</source>
        <translation>Muokkaa tapahtumaa</translation>
    </message>
    <message>
        <location filename="../EventWindow.ui" line="192"/>
        <source>Delete event</source>
        <translation>Poista tapahtuma</translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="133"/>
        <source>From</source>
        <translation>Alkaa</translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="133"/>
        <source>On</source>
        <translation>Ajankohta</translation>
    </message>
    <message>
        <location filename="../EventWindow.cpp" line="203"/>
        <location filename="../EventWindow.cpp" line="224"/>
        <source>No more events</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ExpandingTextEdit</name>
    <message>
        <location filename="../ExpandingTextEdit.cpp" line="101"/>
        <source>Description</source>
        <translation>Kuvaus</translation>
    </message>
</context>
<context>
    <name>JournalEditDialog</name>
    <message>
        <location filename="../JournalEditDialog.ui" line="17"/>
        <source>Calendar</source>
        <translation>Kalenteri</translation>
    </message>
    <message>
        <location filename="../JournalEditDialog.cpp" line="24"/>
        <source>Edit note</source>
        <translation>Muokkaa muistiinpanoa</translation>
    </message>
    <message>
        <location filename="../JournalEditDialog.cpp" line="32"/>
        <source>New note</source>
        <translation>Uusi muistiinpano</translation>
    </message>
</context>
<context>
    <name>JournalsPlug</name>
    <message>
        <location filename="../JournalsPlug.cpp" line="27"/>
        <source>New note</source>
        <translation>Uusi muistiinpano</translation>
    </message>
    <message>
        <location filename="../JournalsPlug.cpp" line="46"/>
        <source>Notes</source>
        <translation>Muistiinpanot</translation>
    </message>
    <message>
        <location filename="../JournalsPlug.cpp" line="120"/>
        <source>Edit</source>
        <translation>Muokkaa</translation>
    </message>
    <message>
        <location filename="../JournalsPlug.cpp" line="121"/>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../MainWindow.cpp" line="56"/>
        <source>Month</source>
        <translation>Kuukausi</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="57"/>
        <source>Week</source>
        <translation>Viikko</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="58"/>
        <source>Agenda</source>
        <translation>Merkinnät</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="59"/>
        <source>Tasks</source>
        <translation>Tehtävät</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="60"/>
        <source>Notes</source>
        <translation>Muistiinpanot</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="61"/>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
</context>
<context>
    <name>MonthPlug</name>
    <message>
        <location filename="../month/MonthPlug.cpp" line="63"/>
        <source>Previous month</source>
        <translation>Edellinen kuukausi</translation>
    </message>
    <message>
        <location filename="../month/MonthPlug.cpp" line="64"/>
        <source>Next month</source>
        <translation>Seuraava kuukausi</translation>
    </message>
    <message>
        <location filename="../month/MonthPlug.cpp" line="65"/>
        <source>Jump to today</source>
        <translation>Siirry tähän päivään</translation>
    </message>
    <message>
        <location filename="../month/MonthPlug.cpp" line="66"/>
        <source>Jump to</source>
        <translation>Siirry</translation>
    </message>
    <message>
        <location filename="../month/MonthPlug.cpp" line="67"/>
        <source>New event</source>
        <translation>Uusi tapahtuma</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../ChangeManager.cpp" line="47"/>
        <source>Unable to edit birthdays</source>
        <translation>Syntymäpäivien muokkaus ei mahdollista</translation>
    </message>
    <message>
        <location filename="../ChangeManager.cpp" line="57"/>
        <source>Delete component?</source>
        <translation>Poista komponentti?</translation>
    </message>
</context>
<context>
    <name>RecurrencePickDialog</name>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="6"/>
        <source>Recurrence</source>
        <translation>Toistuminen</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="28"/>
        <source>Repeat</source>
        <translation>Toista</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="50"/>
        <source>Frequency</source>
        <translation>Toistuminen</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="61"/>
        <source>Daily</source>
        <translation>Päivittäin</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="66"/>
        <source>Weekly</source>
        <translation>Viikoittain</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="71"/>
        <source>Monthly</source>
        <translation>Kuukausittain</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="76"/>
        <source>Yearly</source>
        <translation>Vuosittain</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="84"/>
        <source>Interval</source>
        <translation>Aikaväli</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="108"/>
        <source>Forever</source>
        <translation>Ikuisesti</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="113"/>
        <source>Until</source>
        <translation>Saakka</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.ui" line="118"/>
        <source>Count</source>
        <translation>Kertaa</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickDialog.cpp" line="32"/>
        <source>Done</source>
        <translation>Valmis</translation>
    </message>
</context>
<context>
    <name>RecurrencePickSelector</name>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="28"/>
        <source>Never</source>
        <translation>Ei koskaan</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="30"/>
        <source>External</source>
        <translation>Ulkoinen</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="32"/>
        <source>Every day</source>
        <translation>Joka päivä</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="34"/>
        <source>Every workday</source>
        <translation>Joka arkipäivä</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="36"/>
        <source>Every week</source>
        <translation>Joka viikko</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="38"/>
        <source>Every month</source>
        <translation>Joka kuukausi</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="40"/>
        <source>Every year</source>
        <translation>Joka vuosi</translation>
    </message>
    <message>
        <location filename="../recurrence/RecurrencePickSelector.cpp" line="42"/>
        <source>Complex</source>
        <translation>Monimutkainen</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="6"/>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="32"/>
        <source>Edit calendars</source>
        <translation>Muokkaa kalentereita</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="42"/>
        <source>Delete events</source>
        <translation>Poista tapahtumat</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.ui" line="52"/>
        <source>Delete tasks</source>
        <translation>Poista tehtävät</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.cpp" line="14"/>
        <source>Save</source>
        <translation>Tallenna</translation>
    </message>
    <message>
        <location filename="../settings/SettingsDialog.cpp" line="43"/>
        <source>Never</source>
        <translation>Ei koskaan</translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/SettingsDialog.cpp" line="45"/>
        <location filename="../settings/SettingsDialog.cpp" line="47"/>
        <source>Older than %n week(s)</source>
        <translation>
            <numerusform>Vanhempi kuin %n viikko</numerusform>
            <numerusform>Vanhempi kuin %n viikkoa</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/SettingsDialog.cpp" line="49"/>
        <source>Older than %n month(s)</source>
        <translation>
            <numerusform>Vanhempi kuin %n kuukausi</numerusform>
            <numerusform>Vanhempi kuin %n kuukautta</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../settings/SettingsDialog.cpp" line="51"/>
        <source>Older than %n year(s)</source>
        <translation>
            <numerusform>Vanhempi kuin %n vuosi</numerusform>
            <numerusform>Vanhempi kuin %n vuotta</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>TodoEditDialog</name>
    <message>
        <location filename="../TodoEditDialog.ui" line="28"/>
        <source>Done</source>
        <translation>Valmis</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.ui" line="35"/>
        <source>Date</source>
        <translation>Päivämäärä</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.ui" line="42"/>
        <source>Calendar</source>
        <translation>Kalenteri</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.ui" line="49"/>
        <location filename="../TodoEditDialog.ui" line="61"/>
        <source>Alarm</source>
        <translation>Hälytys</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.cpp" line="44"/>
        <source>Edit task</source>
        <translation>Muokkaa tehtävää</translation>
    </message>
    <message>
        <location filename="../TodoEditDialog.cpp" line="61"/>
        <source>New task</source>
        <translation>Uusi tehtävä</translation>
    </message>
</context>
<context>
    <name>TodoWindow</name>
    <message>
        <location filename="../TodoWindow.ui" line="6"/>
        <source>Task</source>
        <translation>Tehtävä</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="41"/>
        <source>Done</source>
        <translation>Valmis</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="50"/>
        <source>Due</source>
        <translation>Päivämäärä</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="80"/>
        <source>Alarm</source>
        <translation>Hälytys</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="167"/>
        <source>Edit task</source>
        <translation>Muokkaa tehtävää</translation>
    </message>
    <message>
        <location filename="../TodoWindow.ui" line="172"/>
        <source>Delete task</source>
        <translation>Poista tehtävä</translation>
    </message>
</context>
<context>
    <name>TodosPlug</name>
    <message>
        <location filename="../TodosPlug.cpp" line="33"/>
        <source>New task</source>
        <translation>Uusi tehtävä</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="40"/>
        <source>Hide completed</source>
        <translation>Piilota valmiit</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="41"/>
        <source>Delete completed</source>
        <translation>Poista valmiit</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="78"/>
        <source>Tasks</source>
        <translation>Tehtävät</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="198"/>
        <source>Edit</source>
        <translation>Muokkaa</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="199"/>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <location filename="../TodosPlug.cpp" line="224"/>
        <source>Delete completed tasks from all calendars?</source>
        <translation>Poista suoritetut tehtävät kaikista kalentereista?</translation>
    </message>
</context>
<context>
    <name>WeekButton</name>
    <message>
        <location filename="../month/WeekButton.cpp" line="31"/>
        <source>w%1</source>
        <translation>v%1</translation>
    </message>
</context>
<context>
    <name>WeekPlug</name>
    <message>
        <location filename="../week/WeekPlug.cpp" line="42"/>
        <source>Previous week</source>
        <translation>Edellinen viikko</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="43"/>
        <source>Next week</source>
        <translation>Seuraava viikko</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="44"/>
        <source>Jump to today</source>
        <translation>Siirry tähän päivään</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="45"/>
        <source>Jump to</source>
        <translation>Siirry</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="46"/>
        <source>New event</source>
        <translation>Uusi tapahtuma</translation>
    </message>
    <message>
        <location filename="../week/WeekPlug.cpp" line="69"/>
        <source>Week %1 (%2)</source>
        <translation>Viikko %1 (%2)</translation>
    </message>
</context>
<context>
    <name>WeekWidget</name>
    <message>
        <location filename="../week/WeekWidget.cpp" line="357"/>
        <source>All day</source>
        <translation>Koko päivä</translation>
    </message>
</context>
</TS>
